@@ -157,10 +157,10 @@ sub retrieve
   #if ( fileno (MORPHLIST)
   
   my $countinstance = 0;
-  my $pm = new Parallel::ForkManager( $max_processes ); #Sets up the possibility of opening child processes
+  #my $pm = new Parallel::ForkManager( $max_processes ); #Sets up the possibility of opening child processes
   foreach my $instance (@instances)
   {
-    my $pid = $pm->start and next; # Begins the child process
+    #my $pid = $pm->start and next; # Begins the child process
     my %d = %{$instance};
     my $countcase = $d{countcase}; 
     my $countblock = $d{countblock}; 
@@ -840,7 +840,7 @@ $printthis
         }  
       }
     }
-     $pm->finish; # Terminates the child process
+     #$pm->finish; # Terminates the child process
     $countinstance++;
   }
   
@@ -942,11 +942,11 @@ sub report # This function retrieves the results of interest from the texts file
   $" = " ";
   my $repfile;
   #my @convey;
-  my $pm = new Parallel::ForkManager( $max_processes ); #Sets up the possibility of opening child processes
+  #my $pm = new Parallel::ForkManager( $max_processes ); #Sets up the possibility of opening child processes
   my $countinstance = 0;
   foreach my $instance ( @instances )
   {
-    my $pid = $pm->start and next; # Begins the child process
+    #my $pid = $pm->start and next; # Begins the child process
     my %d = %{$instance};
     my $countcase = $d{countcase}; 
     my $countblock = $d{countblock}; 
@@ -1207,7 +1207,7 @@ sub report # This function retrieves the results of interest from the texts file
     #push ( @{ $convey[ $countcase ][ $counblock ] }, $lin );
       say "#Reporting results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance: writing $repfile. ";
     }
-    $pm->finish; # Terminates the child process
+    #$pm->finish; # Terminates the child process
     $countinstance++;
   }
   
